//                                               -*- C++ -*-
/**
 *  @file  LinearNumericalMathFunction.cxx
 *  @brief Abstract top-level class for all distributions
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: LinearNumericalMathFunction.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include "LinearNumericalMathFunction.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Func {

      CLASSNAMEINIT(LinearNumericalMathFunction);

      /* Default constructor */
      LinearNumericalMathFunction::LinearNumericalMathFunction(const NumericalPoint & center,
							       const NumericalPoint & constant,
							       const Matrix & linear)
	: NumericalMathFunction(new LinearNumericalMathEvaluationImplementation(center, constant, linear.transpose()), 
				new ConstantNumericalMathGradientImplementation(linear.transpose()),
				new ConstantNumericalMathHessianImplementation(SymmetricTensor(center.getDimension(), constant.getDimension())))
      {
	// Nothing to do
      }

      /* Comparison operator */
      Bool LinearNumericalMathFunction::operator ==(const LinearNumericalMathFunction & other) const
      {
	return true;
      }
  
      /* String converter */
      String LinearNumericalMathFunction::__repr__() const
      {
	OSS oss;
	oss << "class=" << LinearNumericalMathFunction::GetClassName()
	    << " name=" << getName()
            << " implementation=" << getImplementation()->__repr__();
	return oss;
      }
  
    } /* namespace Func */
  } /* namespace Base */
} /* namespace OpenTURNS */
